@@ -78,19 +78,6 @@ class Disconf:
                         config_list.append(_)
         return config_list
 
-    def _save_item(self, item):
-        """
-        保存配置数据字典至本地文件
-        :param item: 配置数据字典
-        :return:
-        """
-
-        with open(self.__disconf_path, 'w', encoding='utf-8') as f:
-            for k in item:
-                f.write(k + '=' + item[k] + '\n')
-
-        klogger.info('Save disconf path: {}'.format(self.__disconf_path))
-
     def _download_file(self, app, key) -> dict:
         """
         从配置中心获取配置文件
@@ -149,10 +136,12 @@ class Disconf:
                         klogger.info('Load local disconf success.')
             else:
                 klogger.info('Download disconf files finished.')
-                self._save_item(disconf_item)
 
-            for item in disconf_item:
-                klogger.info('disconf_item: {}'.format(item + '=' + disconf_item[item]))
+            for key, value in disconf_item.items():
+                if any([_ in key for _ in ['secret', 'secret'.upper()]]):
+                    klogger.info('disconf_item: {}=MD5({})'.format(key, utils.get_md5(value)))
+                else:
+                    klogger.info('disconf_item: {}={}'.format(key, value))
 
             return disconf_item
         except Exception as e:
